@@ -34,8 +34,9 @@ class Config:
 		self.color = ""
 		self.lastplayed = ""
 		self.format = "mp3"
+		self.rotation = "automatic"
 		#I loop through possible configuration options in this array
-		self.config_opts = ['user','password','format']
+		self.config_opts = ['user','password','format','rotation']
 
 	def write(self): #write the configuration files
 		if not os.path.exists(os.path.expanduser("~")+'/.config'):
@@ -43,7 +44,7 @@ class Config:
 
 		if not os.path.exists(os.path.expanduser("~")+'/.config/pyradio'):
 			os.mkdir(os.path.expanduser("~")+'/.config/pyradio')
-		newfile = "user="+self.user+"\npassword="+self.password+"\n"+"format="+self.format+"\n"
+		newfile = "user="+self.user+"\npassword="+self.password+"\n"+"format="+self.format+"\n"+"rotation="+self.rotation+"\n"
 		f = open(os.path.expanduser("~")+'/.config/pyradio/config', 'w')
 		f.write(newfile)
 		f.close()
@@ -91,6 +92,7 @@ class Panda(QtGui.QMainWindow): #main class
 		self.c = Config() 
 		self.c.load()
 		self.s = snooze ( 0 )
+		self.song = 0
 		self.stimer = QTimer()
 		self.manualPause = False #track manual pausing
 		self.curStation = 0 #Currently playing station
@@ -105,16 +107,6 @@ class Panda(QtGui.QMainWindow): #main class
 		if self.os != "RX-51": #check for N900 
 			self.ui.albumArt.setStyleSheet("background-color: rgb(255, 255, 255);")
 		self.ui.albumArt.setHtml( "<table width='100%' height='100%'><tr height='100%'><td height='100%' valign='middle'><font style='color: #fff'>Pandora is loading... </font></td><tr></table>" )
-		try : #test for rotation and set auto-rotation on
-			self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
-			self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged );
-			screenGeometry=QApplication.desktop().screenGeometry();
-			if screenGeometry.width() > screenGeometry.height():
-				self.portrait = False
-			else:
-				self.portrait = True
-			print" Auto rotation on"
-		except:print "could not autorotate on"
 		QtGui.QApplication.processEvents()
 		self.player.format = self.c.format
 		if not self.c.lastplayed == "": #auto-play last station
@@ -124,6 +116,21 @@ class Panda(QtGui.QMainWindow): #main class
 		self.connect_signals() #called every time orientation changes to connect slots
 		self.stimer.singleShot(100, self.auth)
 		self.doFM(True)
+		try : #test for rotation and set auto-rotation on
+			self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged );
+			if self.c.rotation == 'automatic':
+				self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
+				screenGeometry=QApplication.desktop().screenGeometry();
+				if screenGeometry.width() > screenGeometry.height():
+					self.portrait = False
+				else:
+					self.portrait = True
+				print" Auto rotation on"
+			elif self.c.rotation == 'portrait':
+				self.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
+			elif self.c.rotation == 'landscape':
+				self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+		except:print "could not autorotate on"
 
 #Radio Functions
 	def doPlayPause( self ): #Play if stopped, pause if playing
@@ -149,6 +156,7 @@ class Panda(QtGui.QMainWindow): #main class
 	def doLove( self ): #Love this song
 		self.ui.btnLove.setStyleSheet("background-color: "+ self.c.color +";\n"
 		"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/thumbup_small.png);")
+		self.song[1]["rating"] = 1
 		self.stimer.singleShot(100, self.loveCall)
 		
 	def loveCall( self ):
@@ -256,6 +264,17 @@ class Panda(QtGui.QMainWindow): #main class
 			self.player.getMoreSongs(self.curStation, self.c.format)
 			self.stimer.singleShot(100, self.playNextSong)
 	
+	def stop( self ): #Stop Playing, not currently implemented
+		print "Temp"
+
+	def closeEvent(self, event=None): #Exit application gracefully.. somewhat.
+		self.player.run = 0
+		self.player.close()
+		del self.ui
+		del self.player
+		quit()
+
+#UI Functions
 	def setUi ( self, next=None ): #Update the album graphic and set Love graphic
 		art = next[1]["art"]
 		self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Play_small.png);")
@@ -269,17 +288,6 @@ class Panda(QtGui.QMainWindow): #main class
 
 		self.ui.btnPlay.setStyleSheet("background-image: url(:/img/img/Play_small.png);\nborder: rgb(0, 0, 0);\nbackground-color: "+ self.c.color + ";")
 
-	def stop( self ): #Stop Playing, not currently implemented
-		print "Temp"
-
-	def closeEvent(self, event=None): #Exit application gracefully.. somewhat.
-		self.player.run = 0
-		self.player.close()
-		del self.ui
-		del self.player
-		quit()
-
-#UI Functions
 	def nextDown(self): #change button color
 		self.ui.btnNext.setStyleSheet("background-color: " + self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/next_small.png);")
 
@@ -346,8 +354,9 @@ class Panda(QtGui.QMainWindow): #main class
 		self.ui.lblTime.setWordWrap( True )
 		self.ui.btnLove.setStyleSheet("background-image: url(:/img/img/thumbup_small.png);\nborder: rgb(0, 0, 0);\nbackground-color: rgb(100, 100, 100);")
 		self.ui.btnHate.setStyleSheet("background-color: rgb(100, 100, 100);\nborder: rgb(255, 255, 255);\nbackground-image: url(:/img/img/thumbdwn_small.png);")
-		self.setUi( self.song )
-		self.stimer.singleShot(100, self.getStations)
+		if self.song:
+			self.setUi( self.song )
+			self.stimer.singleShot(100, self.getStations)
 
 	def connect_signals( self ): #connect all signals
 		QtCore.QObject.connect(self.ui.listStations, QtCore.SIGNAL('activated(int)'), self.playStation)
@@ -573,8 +582,10 @@ class Panda(QtGui.QMainWindow): #main class
 		self.settings['radioAuto'] = QRadioButton("Automatic")
 		self.settings['radioPort'] = QRadioButton("Portrait")
 		self.settings['radioLand'] = QRadioButton("Landscape")
-		if not self.portrait:
+		if self.c.rotation == "automatic":
 			self.settings['radioAuto'].setChecked(1)
+		elif self.c.rotation == "landscape":
+			self.settings['radioLand'].setChecked(1)
 		else:
 			self.settings['radioPort'].setChecked(1)
 		self.settings['btnGroup2'].addButton(self.settings['radioAuto'])
@@ -628,11 +639,17 @@ class Panda(QtGui.QMainWindow): #main class
 			self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
 		try:
 			if self.settings['radioAuto'].isChecked():
+				self.c.rotation = 'automatic'
 				self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
+				changed = True
 			elif self.settings['radioPort'].isChecked():
+				self.c.rotation = 'portrait'
 				self.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
+				changed = True
 			elif self.settings['radioLand'].isChecked():
+				self.c.rotation = 'landscape'
 				self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+				changed = True
 		except: print "No Rotation."
 		self.settings = None
 		if changed:
